pub struct EncryptionSyncService { /* private fields */ }Expand description
High-level helper for synchronizing encryption events using sliding sync.
See the module’s documentation for more details.
Implementations
Sourceimpl EncryptionSyncService
impl EncryptionSyncService
Sourcepub async fn new(
client: Client,
poll_and_network_timeouts: Option<(Duration, Duration)>,
) -> Result<Self, Error>
pub async fn new( client: Client, poll_and_network_timeouts: Option<(Duration, Duration)>, ) -> Result<Self, Error>
Creates a new instance of a EncryptionSyncService.
This will create and manage an instance of matrix_sdk::SlidingSync.
Sourcepub fn run_iterations(
self,
permit: OwnedMutexGuard<EncryptionSyncPermit>,
) -> impl Stream<Item = Result<(), Error>>
pub fn run_iterations( self, permit: OwnedMutexGuard<EncryptionSyncPermit>, ) -> impl Stream<Item = Result<(), Error>>
Runs an EncryptionSyncService loop, yielding Ok(()) after each
iteration so the caller can decide whether to continue or stop by
dropping the stream.
Ends without yielding if the cross-process lock is configured but can’t be acquired (another process is expected to run the sync).
Note: the EncryptionSyncPermit parameter ensures that there’s at
most one encryption sync running at any time. See its documentation
for more details.