SyncServiceBuilder

Struct SyncServiceBuilder 

pub struct SyncServiceBuilder { /* private fields */ }

Implementations

Source

impl SyncServiceBuilder

pub fn with_offline_mode(self) -> Self

Enable the “offline” mode for the SyncService.

To learn more about the “offline” mode read the documentation for the State::Offline enum variant.

pub fn with_share_pos(self, enable: bool) -> Self

Whether to turn SlidingSyncBuilder::share_pos on or off.

pub fn with_room_list_conn_id(self, conn_id: String) -> Self

Set a custom conn_id for the room list sliding sync connection.

pub fn with_room_list_timeline_limit(self, limit: u32) -> Self

Set a custom timeline limit for the room list service.

pub fn with_parent_span(self, parent_span: Span) -> Self

Set the parent tracing span to be used for the tasks within this service.

pub async fn build(self) -> Result<SyncService, Error>

Finish setting up the SyncService.

This creates the underlying sliding syncs, and will not start them in the background. The resulting SyncService must be kept alive as long as the sliding syncs are supposed to run.