pub enum LatestEventValue {
None,
Remote {
timestamp: MilliSecondsSinceUnixEpoch,
sender: OwnedUserId,
is_own: bool,
profile: TimelineDetails<Profile>,
content: TimelineItemContent,
},
RemoteInvite {
timestamp: MilliSecondsSinceUnixEpoch,
inviter: Option<OwnedUserId>,
inviter_profile: TimelineDetails<Profile>,
},
Local {
timestamp: MilliSecondsSinceUnixEpoch,
sender: OwnedUserId,
profile: TimelineDetails<Profile>,
content: TimelineItemContent,
state: LatestEventValueLocalState,
},
}Expand description
A simplified version of matrix_sdk_base::latest_event::LatestEventValue
tailored for this timeline module.
Variants
None
No value has been computed yet, or no candidate value was found.
Remote
The latest event represents a remote event.
Fields
timestamp: MilliSecondsSinceUnixEpochThe timestamp of the remote event.
sender: OwnedUserIdThe sender of the remote event.
profile: TimelineDetails<Profile>The sender’s profile.
content: TimelineItemContentThe content of the remote event.
RemoteInvite
The latest event represents an invite to a room.
Fields
timestamp: MilliSecondsSinceUnixEpochThe timestamp of the invite.
inviter: Option<OwnedUserId>The inviter (can be unknown).
inviter_profile: TimelineDetails<Profile>The inviter’s profile (can be unknown).
Local
The latest event represents a local event that is sending, or that cannot be sent, either because a previous local event, or this local event cannot be sent.
Fields
timestamp: MilliSecondsSinceUnixEpochThe timestamp of the local event.
sender: OwnedUserIdThe sender of the remote event.
profile: TimelineDetails<Profile>The sender’s profile.
content: TimelineItemContentThe content of the local event.
state: LatestEventValueLocalStateWhether the local event is sending, has been sent or cannot be sent.