pub enum TimelineEventShieldState {
Red {
code: TimelineEventShieldStateCode,
},
Grey {
code: TimelineEventShieldStateCode,
},
None,
}Expand description
Extends ShieldState to allow for a SentInClear code.
Variants
Red
A red shield with a tooltip containing a message appropriate to the associated code should be presented.
Fields

code: TimelineEventShieldStateCodeA machine-readable representation.
Grey
A grey shield with a tooltip containing a message appropriate to the associated code should be presented.
Fields

code: TimelineEventShieldStateCodeA machine-readable representation.
None
No shield should be presented.