pub enum TimelineEventShieldStateCode {
AuthenticityNotGuaranteed,
UnknownDevice,
UnsignedDevice,
UnverifiedIdentity,
VerificationViolation,
MismatchedSender,
SentInClear,
}Expand description
Extends ShieldStateCode to allow for a SentInClear code.
Variants
AuthenticityNotGuaranteed
Not enough information available to check the authenticity.
UnknownDevice
The sending device isn’t yet known by the Client.
UnsignedDevice
The sending device hasn’t been verified by the sender.
UnverifiedIdentity
The sender hasn’t been verified by the Client’s user.
VerificationViolation
The sender was previously verified but changed their identity.
MismatchedSender
The sender field on the event does not match the owner of the device
that established the Megolm session.
SentInClear
An unencrypted event in an encrypted room.