pub enum TimelineFocus {
Live {
hide_threaded_events: bool,
},
Event {
target: OwnedEventId,
num_context_events: u16,
thread_mode: TimelineEventFocusThreadMode,
},
Thread {
root_event_id: OwnedEventId,
},
PinnedEvents,
}Expand description
What should the timeline focus on?
Variants
Live
Focus on live events, i.e. receive events from sync and append them in real-time.
Fields

hide_threaded_events: boolWhether to hide in-thread replies from the live timeline.
This should be set to true when the client can create
Self::Thread-focused timelines from the thread roots themselves.
Event
Focus on a specific event, e.g. after clicking a permalink.
Thread
Focus on a specific thread
Fields

root_event_id: OwnedEventIdPinnedEvents
Only show pinned events.