pub struct PollState { /* private fields */ }Expand description
Holds the state of a poll.
This struct should be created for each poll start event handled and then updated whenever handling any poll response or poll end event that relates to the same poll start event.
Implementations