pub struct NotificationClientTimeouts {
pub sync_poll_timeout: Duration,
pub sync_network_timeout: Duration,
pub decryption_deadline: Duration,
pub encryption_sync_poll_timeout: Duration,
pub encryption_sync_network_timeout: Duration,
}Expand description
Timeouts applied by a NotificationClient while fetching the content of
notifications.
Fields
sync_poll_timeout: DurationLong-poll timeout of the sliding sync request retrieving the notified events, i.e. how long the homeserver waits for the events to be available before answering.
sync_network_timeout: DurationExtra time allowed for the network round trip of the sliding sync
request retrieving the notified events, on top of
Self::sync_poll_timeout.
decryption_deadline: DurationMaximum time spent waiting for a missing room key, when an event in a notification can’t be decrypted.
This applies to both ways of obtaining the key, so that they give up after the same amount of time:
- When the notification client runs the encryption sync itself, this bounds the time spent running it, once a minimum number of iterations (currently two) have been run. Decryption is attempted after each iteration, so this only bounds the unsuccessful case: once the deadline has passed, no new iteration is started.
- In a
NotificationProcessSetup::SingleProcesssetup where the main encryption sync is already running, the notification client must not run a second one and waits for the running one to receive the key instead. The wait ends as soon as a key for the room is received, so this only bounds the case where the key doesn’t arrive.
In both cases, the event is returned undecrypted once the deadline has passed.
encryption_sync_poll_timeout: DurationLong-poll timeout of each request of the encryption sync run to obtain a missing room key, i.e. how long the homeserver waits for a to-device message to arrive before answering.
Only applies when the notification client runs the encryption sync
itself. Together with Self::decryption_deadline, this determines how
many iterations are run when the homeserver has nothing to return.
encryption_sync_network_timeout: DurationExtra time allowed for the network round trip of each request of the
encryption sync, on top of Self::encryption_sync_poll_timeout. This
is an upper bound on how long a request may take.