pub struct SpaceFilter {
pub space_room: SpaceRoom,
pub level: u8,
pub descendants: Vec<OwnedRoomId>,
}Fields
space_room: SpaceRoomThe underlying SpaceRoom
level: u8The level of the space filter in the tree/hierarchy. At this point in time the filters are limited to the first 2 levels.
descendants: Vec<OwnedRoomId>The room identifiers of the descendants of this space. For top level spaces (level 0) these will be direct descendants while for first level spaces they will be all other descendants, recursively.