#[non_exhaustive]pub enum Error {
Show 15 variants
EventNotInTimeline(TimelineEventItemId),
UnsupportedEvent,
InvalidAttachmentData,
InvalidAttachmentFileName,
FailedSendingAttachment,
FailedSendingRedaction,
FailedToToggleReaction,
UnknownEncryptionState,
Sdk(Error),
EventCacheError(EventCacheError),
PaginationError(PaginationError),
SendQueueError(RoomSendQueueError),
EditError(EditError),
ReplyError(ReplyError),
RedactError(RedactError),
}Expand description
Errors specific to the timeline.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EventNotInTimeline(TimelineEventItemId)
The requested event is not in the timeline.
UnsupportedEvent
The event is currently unsupported for this use case..
InvalidAttachmentData
Couldn’t read the attachment data from the given URL.
InvalidAttachmentFileName
The attachment file name used as a body is invalid.
FailedSendingAttachment
The attachment could not be sent.
FailedSendingRedaction
The redaction could not be sent.
FailedToToggleReaction
The reaction could not be toggled.
UnknownEncryptionState
Couldn’t read the encryption state of the room.
Sdk(Error)
An error from the underlying Matrix SDK.
EventCacheError(EventCacheError)
Something went wrong with the room event cache.
PaginationError(PaginationError)
An error happened during pagination.
SendQueueError(RoomSendQueueError)
An error happened while operating the room’s send queue.
EditError(EditError)
An error happened while attempting to edit an event.
ReplyError(ReplyError)
An error happened while attempting to reply to an event.
RedactError(RedactError)
An error happened while attempting to redact an event.